@@ -12,14 +12,10 @@ def get_input(text):
 
 def run_subprocess(script: str):
     if "rm " in script:
-        logger.warning('UNSAFE SCRIPT')
+        logger.warning("UNSAFE SCRIPT")
         sys.exit()
     try:
-        subprocess.run(script,
-                       shell=True,
-                       check=True,
-                       timeout=30
-                       )
+        subprocess.run(script, shell=True, check=True, timeout=30)
     except subprocess.CalledProcessError as e:
         print(e.output)
         logger.warning(e.output)
@@ -34,15 +30,15 @@ def mins_to_secs(minutes: int):
 
 
 def flip_mode(mode: str):
-    if mode == 'work':
-        logger.debug(f'flip_mode took {mode} returned rest')
-        return 'rest'
+    if mode == "work":
+        logger.debug(f"flip_mode took {mode} returned rest")
+        return "rest"
     else:
-        logger.debug(f'flip_mode took {mode} returned work')
-        return 'work'
+        logger.debug(f"flip_mode took {mode} returned work")
+        return "work"
 
 
 def check_for_file(path):
     is_file = os.path.isfile(path)
-    logger.info(f'check_for_file {is_file}')
+    logger.info(f"check_for_file {path} {is_file}")
     return is_file
